/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IResizer.java 5224 2009-11-08 14:00:33Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.pool.impl.enhanced.internal.resizer.api;


/**
 * A pool resizer can only manage one pool.
 * @author Gael Lalire
 * @param <S> statistics type
 */
public interface IResizer<S> {

    /**
     * Prepare an update (calculate next value of expectedSize).
     * When this method returns the calcul must be complete (no asynchronous mechanism can be used).
     *
     * @param stats statistics
     */
     void prepareUpdate(S stats);

    /**
     * This method grant that eventually at least one call will
     * be made to setExpectedSize, with stats calculated by latest call to
     * prepareUpdate.
     * When this method returns you cannot know if the setExpectedSize have been called (asynchronous mechanism
     * like watchDog or delegation to another thread can be used).
     */
     void update();

     /**
      * Resizer will call method on it.
      * @param resizable a resizable
      */
     void setResizable(final IResizable resizable);

}
